@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 #
 # padelpy/functions.py
-# v.0.1.8
-# Developed in 2019 by Travis Kessler <travis.j.kessler@gmail.com>
+# v.0.1.10
+# Developed in 2021 by Travis Kessler <travis.j.kessler@gmail.com>
 #
 # Contains various functions commonly used with PaDEL-Descriptor
 #
@@ -68,7 +68,8 @@ def from_smiles(smiles, output_csv: str = None, descriptors: bool = True,
                 d_2d=descriptors,
                 d_3d=descriptors,
                 fingerprints=fingerprints,
-                sp_timeout=timeout
+                sp_timeout=timeout,
+                retainorder=True
             )
             break
         except RuntimeError as exception:
